perg
A fast, feature-rich text search tool similar to grep, written in Rust.
This crate provides the core functionality for searching text patterns in files using regular expressions with support for:
- Basic pattern matching with regular expressions
- Case-insensitive matching (
-iflag) - Line number display (
-nflag) - Recursive directory searching (
-rflag) - Context lines around matches (
-B,-A,-Cflags) - Count matching lines (
-cflag) - Show only matching parts (
-oflag) - Limit number of matches (
-mflag) - Extended regular expressions (
-Eflag) - Colorized output (
--colorflag) - Invert match (
-vflag) - Files with/without matches listing (
-l/-Lflags) - Reading from stdin when no file paths are provided
Re-exports
pub use cli::Args;pub use error::PergError;pub use error::Result;pub use search::search_file;pub use search::search_paths;pub use search::search_stdin;pub use search::SearchConfig;